pub struct LazyPseudoDirectoryAsync<T>(/* private fields */);Expand description
A pseudo directory that delays constructing a PseudoDirectory until a request is received.
The intended purpose of LazyPseudoDirectoryAsync is to save memory when presenting data in a
filesystem structure for debug purposes. The directory should not be accessed during regular
system usage otherwise no memory savings will occur.
This is functionally identical to LazyPseudoDirectory, except it is compatible with
ToPseudoDirectoryAsync (i.e. directories with asynchronous initializers). As a tradeoff,
any time the contents are accessed, an async lock must be acquired, which will be less
performant. As such, this should only be used when needed.
Implementations